==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/english/original_sections/admin/menu/admin_menu.lang.inc.php <==
<?php
/*--------------------------------------------------------------------
 admin_menu.lang.inc.php 2020-2-11
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2020 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 -------------------------------------------------------------------*/

$t_language_text_section_content_array = [
    'BOX_ADMIN_ACCESS'            => 'Roles and Permissions',
    'BOX_GAMBIO_STORE'            => 'Gambio Store',
    'BOX_ATTRIBUTES_MANAGER'      => 'Attribute Manager',
    'BOX_BACKUP'                  => 'Database Manager',
    'BOX_BANNER_MANAGER'          => 'Banner Manager',
    'BOX_CACHE'                   => 'Cache',
    'BOX_CAMPAIGNS'               => 'Campaigns',
    'BOX_CAMPAIGNS_REPORT'        => 'Campaign Report',
    'BOX_CATEGORIES'              => 'Categories / Products',
    'BOX_CLEAR_CACHE'             => 'Clear Cache',
    'BOX_CONFIGURATION_1'         => 'My Shop',
    'BOX_CONFIGURATION_10'        => 'Logging Options',
    'BOX_CONFIGURATION_11'        => 'Cache Options',
    'BOX_CONFIGURATION_12'        => 'Email Options',
    'BOX_CONFIGURATION_13'        => 'Download Options',
    'BOX_CONFIGURATION_14'        => 'Performance',
    'BOX_CONFIGURATION_15'        => 'Sessions',
    'BOX_CONFIGURATION_17'        => 'Special Modules',
    'BOX_CONFIGURATION_18'        => 'VAT No.',
    'BOX_CONFIGURATION_19'        => 'Interfaces',
    'BOX_CONFIGURATION_2'         => 'Minimum Values',
    'BOX_CONFIGURATION_22'        => 'Search Options',
    'BOX_CONFIGURATION_3'         => 'Maximum Values',
    'BOX_CONFIGURATION_4'         => 'Image Options',
    'BOX_CONFIGURATION_5'         => 'Customer Details',
    'BOX_CONFIGURATION_7'         => 'Shipping Options',
    'BOX_CONFIGURATION_753'       => 'Shop-Key',
    'BOX_CONFIGURATION_8'         => 'Product Listing Options',
    'BOX_CONFIGURATION_9'         => 'Stock Options',
    'BOX_CONTENT'                 => 'Content Manager',
    'BOX_COUNTRIES'               => 'Countries',
    'BOX_COUPON_ADMIN'            => 'Coupon Admin',
    'BOX_CRONJOBS'                => 'Scheduled tasks',
    'BOX_CURRENCIES'              => 'Currencies',
    'BOX_CUSTOMERS'               => 'Customers',
    'BOX_CUSTOMERS_STATUS'        => 'Customer Groups',
    'BOX_EMAILS'                  => 'Emails',
    'BOX_FILEMANAGER'             => 'File Manager',
    'BOX_FORM_EDITOR'             => 'Form editor',
    'BOX_GEO_ZONES'               => 'Tax Zones',
    'BOX_GM_ANALYTICS'            => 'Tracking-Codes',
    'BOX_GM_BACKUP_FILES_ZIP'     => 'Backup files',
    'BOX_GM_COUNTER'              => 'Counter',
    'BOX_GM_EMAILS'               => 'Edit Email Templates',
    'BOX_GM_FEATURE_CONTROL'      => 'Product-Filter',
    'BOX_GM_GPRINT'               => 'GX-Customizer',
    'BOX_GM_GUESTBOOK'            => 'Guestbook',
    'BOX_GM_ID_STARTS'            => 'ID Starts',
    'BOX_GM_JANOLAW'              => 'janolaw AGB Hosting',
    'BOX_GM_LANG_EDIT'            => 'Edit Text',
    'BOX_GM_LAWS'                 => 'Rights',
    'BOX_GM_LIGHTBOX'             => 'Lightbox Configuration',
    'BOX_GM_LOGO'                 => 'Logo Manager',
    'BOX_GM_META'                 => 'Meta Data',
    'BOX_GM_MISCELLANEOUS'        => 'Miscellaneous',
    'BOX_GM_MODULE_EXPORT'        => 'Customer Export',
    'BOX_GM_OFFLINE'              => 'Shop Online/Offline',
    'BOX_ERROR_PAGES'             => 'Own Error Pages',
    'BOX_GM_PDF'                  => 'Invoice/Packing Slip',
    'BOX_GM_PRODUCT_EXPORT'       => 'Product Export',
    'BOX_GM_SECURITY'             => 'Security Center',
    'BOX_GM_SEO_BOOST'            => 'Gambio SEO Boost',
    'BOX_GM_SITEMAP'              => 'Sitemap Generator',
    'BOX_GM_SLIDER'               => 'Teaser-Slider',
    'BOX_GM_SQL'                  => 'SQL',
    'BOX_GM_STYLE_EDIT'           => 'Template Settings',
    'BOX_GM_TRUSTED_SHOP_ID'      => 'Trusted Shops Seal of Approval',
    'BOX_GV_ADMIN_MAIL'           => 'Mail Gift Voucher',
    'BOX_GV_ADMIN_QUEUE'          => 'Gift Voucher Queue',
    'BOX_GV_ADMIN_SENT'           => 'Gift Vouchers sent',
    'BOX_GV_CONFIG'               => 'Gift Vouchers Configuration',
    'BOX_HEADING_CONFIGURATION'   => 'Configuration',
    'BOX_HEADING_CUSTOMERS'       => 'Customers',
    'BOX_HEADING_FAVS'            => 'Favs',
    'BOX_HEADING_GAMBIO_SEO'      => 'Gambio SEO',
    'BOX_HEADING_GV_ADMIN'        => 'Vouchers',
    'BOX_HEADING_LAYOUT_DESIGN'   => 'Layout / Design',
    'BOX_HEADING_MODULES'         => 'Modules',
    'BOX_HEADING_PRODUCTS'        => 'Catalog',
    'BOX_HEADING_SHOP_SETTINGS'   => 'Shop Settings',
    'BOX_HEADING_STATISTICS'      => 'Statistics',
    'BOX_HEADING_SYSTEM_SETTINGS' => 'System Settings',
    'BOX_HEADING_TOOLS'           => 'Toolbox',
    'BOX_HEADING_ZONE'            => 'Zone / Tax',
    'BOX_IMPORT'                  => 'Products',
    'BOX_IMPORT_OLD'              => 'Products (old)',
    'BOX_INVOICES'                => 'Invoices',
    'BOX_LANGUAGES'               => 'Languages',
    'BOX_MAILBEEZ'                => 'MailBeez Email-Marketing',
    'BOX_MAILBEEZ_SHOPVOTING'     => 'Shopbewertungen',
    'BOX_MANUFACTURERS'           => 'Manufacturers',
    'BOX_MODULE_EXPORT'           => 'Modules-Center',
    'BOX_MODULE_NEWSLETTER'       => 'Newsletter',
    'BOX_ORDER_TOTAL'             => 'Order Total',
    'BOX_ORDERS'                  => 'Orders',
    'BOX_ORDERS_OLD'              => 'Orders (old version)',
    'BOX_ORDERS_STATUS'           => 'Order Status',
    'BOX_ORDERS_XSELL_GROUP'      => 'Cross-sell Groups',
    'BOX_PARCEL_SERVICES'         => 'Parcel services',
    'BOX_PAYMENT'                 => 'Payment Systems',
    'BOX_PAYPAL'                  => 'PayPal',
    'BOX_PRODUCTS_ATTRIBUTES'     => 'Product Options',
    'BOX_PRODUCTS_PURCHASED'      => 'Sold Products',
    'BOX_PRODUCTS_VIEWED'         => 'Viewed Products',
    'BOX_PRODUCTS_VPE'            => 'Packing Unit',
    'BOX_PROPERTIES'              => 'Product Properties',
    'BOX_QUANTITYUNITS'           => 'Quantity Units',
    'BOX_QUICK_EDIT'              => 'QuickEdit',
    'BOX_REVIEWS'                 => 'Product Reviews',
    'BOX_ROBOTS'                  => 'Robots file',
    'BOX_SALES_REPORT'            => 'Sales Report',
    'BOX_SERVER_INFO'             => 'Server Info',
    'BOX_SHIPPING'                => 'Shipping Methods',
    'BOX_SHIPPING_STATUS'         => 'Shipping status',
    'BOX_SHOP_SETTINGS'           => 'Shop Settings',
    'BOX_SHOW_LOGS'               => 'Show logs',
    'BOX_SHOW_LOGS_LEGACY'        => 'Show logs (deprecated)',
    'BOX_SPECIALS'                => 'Special Pricing',
    'BOX_STATIC_SEO_URLS'         => 'Static Pages',
    'BOX_STATS_CUSTOMERS'         => 'Purchasing Statistics',
    'BOX_SYSTEM_SETTINGS'         => 'System Settings',
    'BOX_TAX_CLASSES'             => 'Tax Classes',
    'BOX_TAX_RATES'               => 'Tax Rates',
    'BOX_TIMER'                   => 'Timer',
    'BOX_TOOLS_BLACKLIST'         => 'CC Blacklist',
    'BOX_VERSION_HISTORY'         => 'Version History',
    'BOX_WHOS_ONLINE'             => 'Who is Online',
    'BOX_WITHDRAWALS'             => 'Withdrawals',
    'BOX_YATEGO'                  => 'Yatego',
    'BOX_YOOCHOOSE'               => 'YOOCHOOSE References',
    'BOX_ZONES'                   => 'Zones',
];

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/english/original_sections/admin/menu/admin_menu.lang.inc.php <==
<?php
/*--------------------------------------------------------------------
 admin_menu.lang.inc.php 2021-08-13
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2021 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 -------------------------------------------------------------------*/

$t_language_text_section_content_array = [
    'BOX_ADMIN_ACCESS'            => 'Roles and Permissions',
    'BOX_GAMBIO_STORE'            => 'Gambio Store',
    'BOX_ATTRIBUTES_MANAGER'      => 'Attribute Manager',
    'BOX_BACKUP'                  => 'Database Manager',
    'BOX_BANNER_MANAGER'          => 'Banner Manager',
    'BOX_CACHE'                   => 'Cache',
    'BOX_CAMPAIGNS'               => 'Campaigns',
    'BOX_CAMPAIGNS_REPORT'        => 'Campaign Report',
    'BOX_CATEGORIES'              => 'Categories / Products',
    'BOX_CLEAR_CACHE'             => 'Clear Cache',
    'BOX_CONFIGURATION_1'         => 'My Shop',
    'BOX_CONFIGURATION_10'        => 'Logging Options',
    'BOX_CONFIGURATION_11'        => 'Cache Options',
    'BOX_CONFIGURATION_12'        => 'Email Options',
    'BOX_CONFIGURATION_13'        => 'Download Options',
    'BOX_CONFIGURATION_14'        => 'Performance',
    'BOX_CONFIGURATION_15'        => 'Sessions',
    'BOX_CONFIGURATION_17'        => 'Special Modules',
    'BOX_CONFIGURATION_18'        => 'VAT No.',
    'BOX_CONFIGURATION_19'        => 'Interfaces',
    'BOX_CONFIGURATION_2'         => 'Minimum Values',
    'BOX_CONFIGURATION_22'        => 'Search Options',
    'BOX_CONFIGURATION_3'         => 'Maximum Values',
    'BOX_CONFIGURATION_4'         => 'Image Options',
    'BOX_CONFIGURATION_5'         => 'Customer Details',
    'BOX_CONFIGURATION_7'         => 'Shipping Options',
    'BOX_CONFIGURATION_753'       => 'Shop-Key',
    'BOX_CONFIGURATION_8'         => 'Product Listing Options',
    'BOX_CONFIGURATION_9'         => 'Stock Options',
    'BOX_CONTENT'                 => 'Content Manager',
    'BOX_COUNTRIES'               => 'Countries',
    'BOX_COUPON_ADMIN'            => 'Coupon Admin',
    'BOX_CRONJOBS'                => 'Scheduled tasks',
    'BOX_CURRENCIES'              => 'Currencies',
    'BOX_CUSTOMERS'               => 'Customers',
    'BOX_CUSTOMERS_STATUS'        => 'Customer Groups',
    'BOX_EMAILS'                  => 'Emails',
    'BOX_FILEMANAGER'             => 'File Manager',
    'BOX_FORM_EDITOR'             => 'Form editor',
    'BOX_GEO_ZONES'               => 'Tax Zones',
    'BOX_GM_ANALYTICS'            => 'Tracking-Codes',
    'BOX_GM_BACKUP_FILES_ZIP'     => 'Backup files',
    'BOX_GM_COUNTER'              => 'Counter',
    'BOX_GM_EMAILS'               => 'Edit Email Templates',
    'BOX_GM_FEATURE_CONTROL'      => 'Product-Filter',
    'BOX_GM_GPRINT'               => 'GX-Customizer',
    'BOX_GM_ID_STARTS'            => 'ID Starts',
    'BOX_GM_JANOLAW'              => 'janolaw AGB Hosting',
    'BOX_GM_LANG_EDIT'            => 'Edit Text',
    'BOX_GM_LAWS'                 => 'Rights',
    'BOX_GM_LIGHTBOX'             => 'Lightbox Configuration',
    'BOX_GM_LOGO'                 => 'Logo Manager',
    'BOX_GM_META'                 => 'Meta Data',
    'BOX_GM_MISCELLANEOUS'        => 'Miscellaneous',
    'BOX_GM_MODULE_EXPORT'        => 'Customer Export',
    'BOX_GM_OFFLINE'              => 'Shop Online/Offline',
    'BOX_ERROR_PAGES'             => 'Own Error Pages',
    'BOX_GM_PDF'                  => 'Invoice/Packing Slip',
    'BOX_GM_PRODUCT_EXPORT'       => 'Product Export',
    'BOX_GM_SECURITY'             => 'Security Center',
    'BOX_GM_SEO_BOOST'            => 'Gambio SEO Boost',
    'BOX_GM_SITEMAP'              => 'Sitemap Generator',
    'BOX_GM_SLIDER'               => 'Teaser-Slider',
    'BOX_GM_SQL'                  => 'SQL',
    'BOX_GM_STYLE_EDIT'           => 'Edit Theme',
    'BOX_GM_TRUSTED_SHOP_ID'      => 'Trusted Shops Seal of Approval',
    'BOX_GV_ADMIN_MAIL'           => 'Mail Gift Voucher',
    'BOX_GV_ADMIN_QUEUE'          => 'Gift Voucher Queue',
    'BOX_GV_ADMIN_SENT'           => 'Gift Vouchers sent',
    'BOX_GV_CONFIG'               => 'Gift Vouchers Configuration',
    'BOX_HEADING_CONFIGURATION'   => 'Configuration',
    'BOX_HEADING_CUSTOMERS'       => 'Customers',
    'BOX_HEADING_FAVS'            => 'Favs',
    'BOX_HEADING_GAMBIO_SEO'      => 'Gambio SEO',
    'BOX_HEADING_GV_ADMIN'        => 'Vouchers',
    'BOX_HEADING_LAYOUT_DESIGN'   => 'Content',
    'BOX_HEADING_MODULES'         => 'Modules',
    'BOX_HEADING_PRODUCTS'        => 'Catalog',
    'BOX_HEADING_SHOP_SETTINGS'   => 'Settings',
    'BOX_HEADING_STATISTICS'      => 'Statistics',
    'BOX_HEADING_SYSTEM_SETTINGS' => 'System Settings',
    'BOX_HEADING_TOOLS'           => 'Toolbox',
    'BOX_HEADING_ZONE'            => 'Zone / Tax',
    'BOX_IMPORT'                  => 'Import/Export',
    'BOX_IMPORT_OLD'              => 'Products Import (old)',
    'BOX_INVOICES'                => 'Invoices',
    'BOX_LANGUAGES'               => 'Languages',
    'BOX_MAILBEEZ'                => 'MailBeez Email-Marketing',
    'BOX_MAILBEEZ_SHOPVOTING'     => 'Shopbewertungen',
    'BOX_MANUFACTURERS'           => 'Manufacturers',
    'BOX_MODULE_EXPORT'           => 'Modules-Center',
    'BOX_MODULE_NEWSLETTER'       => 'Newsletter',
    'BOX_ORDER_TOTAL'             => 'Order Total',
    'BOX_ORDERS'                  => 'Orders',
    'BOX_ORDERS_OLD'              => 'Orders (old version)',
    'BOX_ORDERS_STATUS'           => 'Order Status',
    'BOX_ORDERS_XSELL_GROUP'      => 'Cross-sell Groups',
    'BOX_PARCEL_SERVICES'         => 'Parcel services',
    'BOX_PAYMENT'                 => 'Payment Systems',
    'BOX_PAYPAL'                  => 'PayPal',
    'BOX_PRODUCTS_ATTRIBUTES'     => 'Product Options',
    'BOX_PRODUCTS_PURCHASED'      => 'Sold Products',
    'BOX_PRODUCTS_VIEWED'         => 'Viewed Products',
    'BOX_PRODUCTS_VPE'            => 'Packing Unit',
    'BOX_QUANTITYUNITS'           => 'Quantity Units',
    'BOX_QUICK_EDIT'              => 'QuickEdit',
    'BOX_REDIRECT_RULES'          => 'Redirect rules',
    'BOX_REVIEWS'                 => 'Product Reviews',
    'BOX_ROBOTS'                  => 'Robots file',
    'BOX_SALES_REPORT'            => 'Sales Report',
    'BOX_SERVER_INFO'             => 'Server Info',
    'BOX_SHIPPING'                => 'Shipping Methods',
    'BOX_SHIPPING_STATUS'         => 'Shipping status',
    'BOX_SHOP_SETTINGS'           => 'Settings',
    'BOX_SHOW_LOGS'               => 'Show logs',
    'BOX_SHOW_LOGS_LEGACY'        => 'Show logs (deprecated)',
    'BOX_SPECIALS'                => 'Special Pricing',
    'BOX_STATIC_SEO_URLS'         => 'Static Pages',
    'BOX_STATS_CUSTOMERS'         => 'Purchasing Statistics',
    'BOX_SYSTEM_SETTINGS'         => 'System Settings',
    'BOX_TAX_CLASSES'             => 'Tax Classes',
    'BOX_TAX_RATES'               => 'Tax Rates',
    'BOX_TIMER'                   => 'Timer',
    'BOX_TOOLS_BLACKLIST'         => 'CC Blacklist',
    'BOX_VERSION_HISTORY'         => 'Version History',
    'BOX_WHOS_ONLINE'             => 'Who is Online',
    'BOX_WITHDRAWALS'             => 'Withdrawals',
    'BOX_YATEGO'                  => 'Yatego',
    'BOX_ZONES'                   => 'Zones',
    'BOX_DELETE_STATS'            => 'Delete statistics',
    'BOX_DELETE_IMAGES'           => 'Delete Product Images',
    'BOX_SHOW_STOCK'              => 'Show stock',
    'BOX_STATISTICS_OVERVIEW'     => 'Overview',
    'BOX_OPTIONS'                 => 'Options',
    'BOX_DOWNLOAD_OPTIONS'        => 'Downloads',
];
